Changelog
=========


1.0 (2022-04-14)
----------------

- initial final release


1.0b3 (2021-02-24)
------------------

- Fix viewlet issue when imagemap field is None
  [MrTango]


1.0b2 (2021-01-26)
------------------

- Prevent trace when imagemap behavior field does not exist on current page.
  [MrTango]


1.0b1 (2021-01-22)
------------------

- Initial release.
  [MrTango]
